using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using System.Reflection;

using Betfair.Gamex.API.Entities;

using Poker.Classes;

namespace Poker.Controls.GameView
{
	/// <summary>
	/// Shows the texas holdem game
	/// </summary>
    public class TexasHoldemView : Poker.Controls.GameView.GameViewBase, IGameControl
	{
		#region Form Controls
		/// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.Windows.Forms.PictureBox CommunityCard1;
		private System.Windows.Forms.PictureBox CommunityCard2;
		private System.Windows.Forms.PictureBox CommunityCard3;
		private System.Windows.Forms.PictureBox CommunityCard4;
		private System.Windows.Forms.PictureBox CommunityCard5;
		private System.Windows.Forms.PictureBox Player1Card1;
		private System.Windows.Forms.PictureBox Player1Card2;
		private System.Windows.Forms.PictureBox Player2Card2;
		private System.Windows.Forms.PictureBox Player2Card1;
		private System.Windows.Forms.PictureBox Player3Card2;
		private System.Windows.Forms.PictureBox Player3Card1;
		private System.Windows.Forms.PictureBox Player4Card2;
		private System.Windows.Forms.PictureBox Player4Card1;
		private System.Windows.Forms.Label GameTitleLabel;
		private System.Windows.Forms.Label DealLabel;
		private System.Windows.Forms.Label PreFlopLabel;
		private System.Windows.Forms.Label FlopLabel;
		private System.Windows.Forms.Label TurnLabel;
		private System.Windows.Forms.Label RiverLabel;
		private System.Windows.Forms.PictureBox ProgressBar;
        private System.Windows.Forms.PictureBox ProgressGrey;
        private System.Windows.Forms.Label Player2StatusLabel;
        private System.Windows.Forms.Label Player3StatusLabel;
        private System.Windows.Forms.Label Player4StatusLabel;
		private System.Windows.Forms.Label SuspendedLabel;
		private Poker.Controls.OddsPanel Player1Price;
		private Poker.Controls.OddsPanel Player2Price;
        private Poker.Controls.OddsPanel Player3Price;
        private Poker.Controls.OddsPanel Player1LayPrice;
        private Poker.Controls.OddsPanel Player3LayPrice;
        private Poker.Controls.OddsPanel Player4LayPrice;
        private System.Windows.Forms.Label Player1StatusLabel;
		private System.Windows.Forms.Label Player1DescriptionLabel;
		private System.Windows.Forms.Label Player2DescriptionLabel;
		private System.Windows.Forms.Label Player3DescriptionLabel;
		private System.Windows.Forms.Label Player4DescriptionLabel;
        private OddsPanel Player4Price;
        private OddsPanel Player2LayPrice;
		#endregion

        private channelSnapshot channelSnapshot;
        private MainForm m_Parent;
        private WPFApuestas WPFControl;

        public int roundId = 0;
        public gameDataObject[] gameData;
        public marketSnapshot market;
        public selectionSnapshot player1Selection;
        public selectionSnapshot player2Selection;
        public selectionSnapshot player3Selection;
        public selectionSnapshot player4Selection;

		public event ShowBetPlaceHandler ShowBetPlacement;
		public event ClearBetsHandler ClearBets;
        
        /// <summary>
        /// Constructor
        /// </summary>
        public TexasHoldemView(MainForm parent)
		{
			InitializeComponent();
            m_Parent = parent;

            //Control de apuestas. Instanciamos el componente y lo hacemos visible.
            WPFControl = (WPFApuestas)m_Parent.elementHost1.Child;
            WPFControl.FPrincipal = m_Parent;
            WPFControl.TexasControl = this;
            m_Parent.elementHost1.Visible = true;
		}

        #region Component Designer generated code
        /// <summary> 
        /// Required method for Designer support - do not modify 
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            System.Windows.Forms.Label CommunityCardsLabel;
            System.Windows.Forms.Label Player1Label;
            System.Windows.Forms.Label Player2Label;
            System.Windows.Forms.Label Player3Label;
            System.Windows.Forms.Label Player4Label;
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(TexasHoldemView));
            this.CommunityCard1 = new System.Windows.Forms.PictureBox();
            this.CommunityCard2 = new System.Windows.Forms.PictureBox();
            this.CommunityCard3 = new System.Windows.Forms.PictureBox();
            this.CommunityCard4 = new System.Windows.Forms.PictureBox();
            this.CommunityCard5 = new System.Windows.Forms.PictureBox();
            this.Player1Card1 = new System.Windows.Forms.PictureBox();
            this.Player1Card2 = new System.Windows.Forms.PictureBox();
            this.Player2Card2 = new System.Windows.Forms.PictureBox();
            this.Player2Card1 = new System.Windows.Forms.PictureBox();
            this.Player3Card2 = new System.Windows.Forms.PictureBox();
            this.Player3Card1 = new System.Windows.Forms.PictureBox();
            this.Player4Card2 = new System.Windows.Forms.PictureBox();
            this.Player4Card1 = new System.Windows.Forms.PictureBox();
            this.GameTitleLabel = new System.Windows.Forms.Label();
            this.DealLabel = new System.Windows.Forms.Label();
            this.PreFlopLabel = new System.Windows.Forms.Label();
            this.FlopLabel = new System.Windows.Forms.Label();
            this.TurnLabel = new System.Windows.Forms.Label();
            this.RiverLabel = new System.Windows.Forms.Label();
            this.ProgressBar = new System.Windows.Forms.PictureBox();
            this.ProgressGrey = new System.Windows.Forms.PictureBox();
            this.Player1StatusLabel = new System.Windows.Forms.Label();
            this.Player2StatusLabel = new System.Windows.Forms.Label();
            this.Player3StatusLabel = new System.Windows.Forms.Label();
            this.Player4StatusLabel = new System.Windows.Forms.Label();
            this.SuspendedLabel = new System.Windows.Forms.Label();
            this.Player1DescriptionLabel = new System.Windows.Forms.Label();
            this.Player2DescriptionLabel = new System.Windows.Forms.Label();
            this.Player3DescriptionLabel = new System.Windows.Forms.Label();
            this.Player4DescriptionLabel = new System.Windows.Forms.Label();
            this.Player4LayPrice = new Poker.Controls.OddsPanel();
            this.Player3LayPrice = new Poker.Controls.OddsPanel();
            this.Player2LayPrice = new Poker.Controls.OddsPanel();
            this.Player1LayPrice = new Poker.Controls.OddsPanel();
            this.Player4Price = new Poker.Controls.OddsPanel();
            this.Player3Price = new Poker.Controls.OddsPanel();
            this.Player2Price = new Poker.Controls.OddsPanel();
            this.Player1Price = new Poker.Controls.OddsPanel();
            CommunityCardsLabel = new System.Windows.Forms.Label();
            Player1Label = new System.Windows.Forms.Label();
            Player2Label = new System.Windows.Forms.Label();
            Player3Label = new System.Windows.Forms.Label();
            Player4Label = new System.Windows.Forms.Label();
            ((System.ComponentModel.ISupportInitialize)(this.CommunityCard1)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.CommunityCard2)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.CommunityCard3)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.CommunityCard4)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.CommunityCard5)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player1Card1)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player1Card2)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player2Card2)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player2Card1)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player3Card2)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player3Card1)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player4Card2)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player4Card1)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.ProgressBar)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.ProgressGrey)).BeginInit();
            this.SuspendLayout();
            // 
            // CommunityCardsLabel
            // 
            CommunityCardsLabel.BackColor = System.Drawing.Color.Transparent;
            CommunityCardsLabel.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            CommunityCardsLabel.ForeColor = System.Drawing.Color.Black;
            CommunityCardsLabel.Location = new System.Drawing.Point(90, 43);
            CommunityCardsLabel.Name = "CommunityCardsLabel";
            CommunityCardsLabel.Size = new System.Drawing.Size(88, 14);
            CommunityCardsLabel.TabIndex = 21;
            CommunityCardsLabel.Text = "Cartas comunes:";
            // 
            // Player1Label
            // 
            Player1Label.BackColor = System.Drawing.Color.White;
            Player1Label.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            Player1Label.ForeColor = System.Drawing.Color.Black;
            Player1Label.Location = new System.Drawing.Point(21, 176);
            Player1Label.Name = "Player1Label";
            Player1Label.Size = new System.Drawing.Size(64, 14);
            Player1Label.TabIndex = 22;
            Player1Label.Text = "Jugador 1";
            Player1Label.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // Player2Label
            // 
            Player2Label.BackColor = System.Drawing.Color.White;
            Player2Label.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            Player2Label.ForeColor = System.Drawing.Color.Black;
            Player2Label.Location = new System.Drawing.Point(126, 176);
            Player2Label.Name = "Player2Label";
            Player2Label.Size = new System.Drawing.Size(64, 14);
            Player2Label.TabIndex = 24;
            Player2Label.Text = "Jugador 2";
            Player2Label.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // Player3Label
            // 
            Player3Label.BackColor = System.Drawing.Color.White;
            Player3Label.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            Player3Label.ForeColor = System.Drawing.Color.Black;
            Player3Label.Location = new System.Drawing.Point(232, 176);
            Player3Label.Name = "Player3Label";
            Player3Label.Size = new System.Drawing.Size(64, 14);
            Player3Label.TabIndex = 26;
            Player3Label.Text = "Jugador 3";
            Player3Label.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // Player4Label
            // 
            Player4Label.BackColor = System.Drawing.Color.White;
            Player4Label.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            Player4Label.ForeColor = System.Drawing.Color.Black;
            Player4Label.Location = new System.Drawing.Point(336, 176);
            Player4Label.Name = "Player4Label";
            Player4Label.Size = new System.Drawing.Size(64, 14);
            Player4Label.TabIndex = 28;
            Player4Label.Text = "Jugador 4";
            Player4Label.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // CommunityCard1
            // 
            this.CommunityCard1.BackColor = System.Drawing.Color.White;
            this.CommunityCard1.Image = ((System.Drawing.Image)(resources.GetObject("CommunityCard1.Image")));
            this.CommunityCard1.Location = new System.Drawing.Point(92, 60);
            this.CommunityCard1.Name = "CommunityCard1";
            this.CommunityCard1.Size = new System.Drawing.Size(44, 60);
            this.CommunityCard1.TabIndex = 0;
            this.CommunityCard1.TabStop = false;
            // 
            // CommunityCard2
            // 
            this.CommunityCard2.BackColor = System.Drawing.Color.White;
            this.CommunityCard2.Image = ((System.Drawing.Image)(resources.GetObject("CommunityCard2.Image")));
            this.CommunityCard2.Location = new System.Drawing.Point(140, 60);
            this.CommunityCard2.Name = "CommunityCard2";
            this.CommunityCard2.Size = new System.Drawing.Size(44, 60);
            this.CommunityCard2.TabIndex = 1;
            this.CommunityCard2.TabStop = false;
            // 
            // CommunityCard3
            // 
            this.CommunityCard3.BackColor = System.Drawing.Color.White;
            this.CommunityCard3.Image = ((System.Drawing.Image)(resources.GetObject("CommunityCard3.Image")));
            this.CommunityCard3.Location = new System.Drawing.Point(188, 60);
            this.CommunityCard3.Name = "CommunityCard3";
            this.CommunityCard3.Size = new System.Drawing.Size(44, 60);
            this.CommunityCard3.TabIndex = 2;
            this.CommunityCard3.TabStop = false;
            // 
            // CommunityCard4
            // 
            this.CommunityCard4.BackColor = System.Drawing.Color.White;
            this.CommunityCard4.Image = ((System.Drawing.Image)(resources.GetObject("CommunityCard4.Image")));
            this.CommunityCard4.Location = new System.Drawing.Point(236, 60);
            this.CommunityCard4.Name = "CommunityCard4";
            this.CommunityCard4.Size = new System.Drawing.Size(44, 60);
            this.CommunityCard4.TabIndex = 3;
            this.CommunityCard4.TabStop = false;
            // 
            // CommunityCard5
            // 
            this.CommunityCard5.BackColor = System.Drawing.Color.White;
            this.CommunityCard5.Image = ((System.Drawing.Image)(resources.GetObject("CommunityCard5.Image")));
            this.CommunityCard5.Location = new System.Drawing.Point(284, 60);
            this.CommunityCard5.Name = "CommunityCard5";
            this.CommunityCard5.Size = new System.Drawing.Size(44, 60);
            this.CommunityCard5.TabIndex = 4;
            this.CommunityCard5.TabStop = false;
            // 
            // Player1Card1
            // 
            this.Player1Card1.BackColor = System.Drawing.Color.White;
            this.Player1Card1.Image = ((System.Drawing.Image)(resources.GetObject("Player1Card1.Image")));
            this.Player1Card1.Location = new System.Drawing.Point(22, 138);
            this.Player1Card1.Name = "Player1Card1";
            this.Player1Card1.Size = new System.Drawing.Size(30, 35);
            this.Player1Card1.TabIndex = 5;
            this.Player1Card1.TabStop = false;
            // 
            // Player1Card2
            // 
            this.Player1Card2.BackColor = System.Drawing.Color.White;
            this.Player1Card2.Image = ((System.Drawing.Image)(resources.GetObject("Player1Card2.Image")));
            this.Player1Card2.Location = new System.Drawing.Point(54, 138);
            this.Player1Card2.Name = "Player1Card2";
            this.Player1Card2.Size = new System.Drawing.Size(30, 35);
            this.Player1Card2.TabIndex = 6;
            this.Player1Card2.TabStop = false;
            // 
            // Player2Card2
            // 
            this.Player2Card2.BackColor = System.Drawing.Color.White;
            this.Player2Card2.Image = ((System.Drawing.Image)(resources.GetObject("Player2Card2.Image")));
            this.Player2Card2.Location = new System.Drawing.Point(159, 138);
            this.Player2Card2.Name = "Player2Card2";
            this.Player2Card2.Size = new System.Drawing.Size(30, 35);
            this.Player2Card2.TabIndex = 8;
            this.Player2Card2.TabStop = false;
            // 
            // Player2Card1
            // 
            this.Player2Card1.BackColor = System.Drawing.Color.White;
            this.Player2Card1.Image = ((System.Drawing.Image)(resources.GetObject("Player2Card1.Image")));
            this.Player2Card1.Location = new System.Drawing.Point(127, 138);
            this.Player2Card1.Name = "Player2Card1";
            this.Player2Card1.Size = new System.Drawing.Size(30, 35);
            this.Player2Card1.TabIndex = 7;
            this.Player2Card1.TabStop = false;
            // 
            // Player3Card2
            // 
            this.Player3Card2.BackColor = System.Drawing.Color.White;
            this.Player3Card2.Image = ((System.Drawing.Image)(resources.GetObject("Player3Card2.Image")));
            this.Player3Card2.Location = new System.Drawing.Point(264, 138);
            this.Player3Card2.Name = "Player3Card2";
            this.Player3Card2.Size = new System.Drawing.Size(30, 35);
            this.Player3Card2.TabIndex = 10;
            this.Player3Card2.TabStop = false;
            // 
            // Player3Card1
            // 
            this.Player3Card1.BackColor = System.Drawing.Color.White;
            this.Player3Card1.Image = ((System.Drawing.Image)(resources.GetObject("Player3Card1.Image")));
            this.Player3Card1.Location = new System.Drawing.Point(232, 138);
            this.Player3Card1.Name = "Player3Card1";
            this.Player3Card1.Size = new System.Drawing.Size(30, 35);
            this.Player3Card1.TabIndex = 9;
            this.Player3Card1.TabStop = false;
            // 
            // Player4Card2
            // 
            this.Player4Card2.BackColor = System.Drawing.Color.White;
            this.Player4Card2.Image = ((System.Drawing.Image)(resources.GetObject("Player4Card2.Image")));
            this.Player4Card2.Location = new System.Drawing.Point(369, 138);
            this.Player4Card2.Name = "Player4Card2";
            this.Player4Card2.Size = new System.Drawing.Size(30, 35);
            this.Player4Card2.TabIndex = 12;
            this.Player4Card2.TabStop = false;
            // 
            // Player4Card1
            // 
            this.Player4Card1.BackColor = System.Drawing.Color.White;
            this.Player4Card1.Image = ((System.Drawing.Image)(resources.GetObject("Player4Card1.Image")));
            this.Player4Card1.Location = new System.Drawing.Point(337, 138);
            this.Player4Card1.Name = "Player4Card1";
            this.Player4Card1.Size = new System.Drawing.Size(30, 35);
            this.Player4Card1.TabIndex = 11;
            this.Player4Card1.TabStop = false;
            // 
            // GameTitleLabel
            // 
            this.GameTitleLabel.BackColor = System.Drawing.Color.Transparent;
            this.GameTitleLabel.Font = new System.Drawing.Font("Tahoma", 8.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.GameTitleLabel.ForeColor = System.Drawing.Color.Black;
            this.GameTitleLabel.Location = new System.Drawing.Point(90, 26);
            this.GameTitleLabel.Name = "GameTitleLabel";
            this.GameTitleLabel.Size = new System.Drawing.Size(223, 16);
            this.GameTitleLabel.TabIndex = 13;
            this.GameTitleLabel.Text = "Cargando el juego Poker Texas Holdem...";
            // 
            // DealLabel
            // 
            this.DealLabel.BackColor = System.Drawing.Color.Transparent;
            this.DealLabel.Font = new System.Drawing.Font("Tahoma", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.DealLabel.ForeColor = System.Drawing.Color.Black;
            this.DealLabel.Location = new System.Drawing.Point(357, 56);
            this.DealLabel.Name = "DealLabel";
            this.DealLabel.Size = new System.Drawing.Size(41, 16);
            this.DealLabel.TabIndex = 14;
            this.DealLabel.Text = "Deal";
            this.DealLabel.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // PreFlopLabel
            // 
            this.PreFlopLabel.BackColor = System.Drawing.Color.Transparent;
            this.PreFlopLabel.Font = new System.Drawing.Font("Tahoma", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.PreFlopLabel.ForeColor = System.Drawing.Color.Black;
            this.PreFlopLabel.Location = new System.Drawing.Point(357, 73);
            this.PreFlopLabel.Name = "PreFlopLabel";
            this.PreFlopLabel.Size = new System.Drawing.Size(55, 11);
            this.PreFlopLabel.TabIndex = 15;
            this.PreFlopLabel.Text = "Preflop";
            this.PreFlopLabel.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // FlopLabel
            // 
            this.FlopLabel.BackColor = System.Drawing.Color.Transparent;
            this.FlopLabel.Font = new System.Drawing.Font("Tahoma", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.FlopLabel.ForeColor = System.Drawing.Color.Black;
            this.FlopLabel.Location = new System.Drawing.Point(357, 85);
            this.FlopLabel.Name = "FlopLabel";
            this.FlopLabel.Size = new System.Drawing.Size(41, 11);
            this.FlopLabel.TabIndex = 16;
            this.FlopLabel.Text = "Flop";
            this.FlopLabel.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // TurnLabel
            // 
            this.TurnLabel.BackColor = System.Drawing.Color.Transparent;
            this.TurnLabel.Font = new System.Drawing.Font("Tahoma", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.TurnLabel.ForeColor = System.Drawing.Color.Black;
            this.TurnLabel.Location = new System.Drawing.Point(357, 97);
            this.TurnLabel.Name = "TurnLabel";
            this.TurnLabel.Size = new System.Drawing.Size(41, 11);
            this.TurnLabel.TabIndex = 17;
            this.TurnLabel.Text = "Turn";
            this.TurnLabel.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // RiverLabel
            // 
            this.RiverLabel.BackColor = System.Drawing.Color.Transparent;
            this.RiverLabel.Font = new System.Drawing.Font("Tahoma", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.RiverLabel.ForeColor = System.Drawing.Color.Black;
            this.RiverLabel.Location = new System.Drawing.Point(357, 109);
            this.RiverLabel.Name = "RiverLabel";
            this.RiverLabel.Size = new System.Drawing.Size(41, 11);
            this.RiverLabel.TabIndex = 18;
            this.RiverLabel.Text = "River";
            this.RiverLabel.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
            // 
            // ProgressBar
            // 
            this.ProgressBar.Image = ((System.Drawing.Image)(resources.GetObject("ProgressBar.Image")));
            this.ProgressBar.Location = new System.Drawing.Point(347, 58);
            this.ProgressBar.Name = "ProgressBar";
            this.ProgressBar.Size = new System.Drawing.Size(7, 63);
            this.ProgressBar.TabIndex = 19;
            this.ProgressBar.TabStop = false;
            // 
            // ProgressGrey
            // 
            this.ProgressGrey.Image = ((System.Drawing.Image)(resources.GetObject("ProgressGrey.Image")));
            this.ProgressGrey.Location = new System.Drawing.Point(347, 58);
            this.ProgressGrey.Name = "ProgressGrey";
            this.ProgressGrey.Size = new System.Drawing.Size(7, 0);
            this.ProgressGrey.TabIndex = 20;
            this.ProgressGrey.TabStop = false;
            // 
            // Player1StatusLabel
            // 
            this.Player1StatusLabel.BackColor = System.Drawing.Color.Green;
            this.Player1StatusLabel.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.Player1StatusLabel.ForeColor = System.Drawing.Color.White;
            this.Player1StatusLabel.Location = new System.Drawing.Point(21, 191);
            this.Player1StatusLabel.Name = "Player1StatusLabel";
            this.Player1StatusLabel.Size = new System.Drawing.Size(64, 14);
            this.Player1StatusLabel.TabIndex = 23;
            this.Player1StatusLabel.Text = "Activo";
            this.Player1StatusLabel.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // Player2StatusLabel
            // 
            this.Player2StatusLabel.BackColor = System.Drawing.Color.Green;
            this.Player2StatusLabel.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.Player2StatusLabel.ForeColor = System.Drawing.Color.White;
            this.Player2StatusLabel.Location = new System.Drawing.Point(126, 191);
            this.Player2StatusLabel.Name = "Player2StatusLabel";
            this.Player2StatusLabel.Size = new System.Drawing.Size(64, 14);
            this.Player2StatusLabel.TabIndex = 25;
            this.Player2StatusLabel.Text = "Activo";
            this.Player2StatusLabel.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // Player3StatusLabel
            // 
            this.Player3StatusLabel.BackColor = System.Drawing.Color.Green;
            this.Player3StatusLabel.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.Player3StatusLabel.ForeColor = System.Drawing.Color.White;
            this.Player3StatusLabel.Location = new System.Drawing.Point(232, 191);
            this.Player3StatusLabel.Name = "Player3StatusLabel";
            this.Player3StatusLabel.Size = new System.Drawing.Size(64, 14);
            this.Player3StatusLabel.TabIndex = 27;
            this.Player3StatusLabel.Text = "Activo";
            this.Player3StatusLabel.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // Player4StatusLabel
            // 
            this.Player4StatusLabel.BackColor = System.Drawing.Color.Green;
            this.Player4StatusLabel.Font = new System.Drawing.Font("Microsoft Sans Serif", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.Player4StatusLabel.ForeColor = System.Drawing.Color.White;
            this.Player4StatusLabel.Location = new System.Drawing.Point(336, 191);
            this.Player4StatusLabel.Name = "Player4StatusLabel";
            this.Player4StatusLabel.Size = new System.Drawing.Size(64, 14);
            this.Player4StatusLabel.TabIndex = 29;
            this.Player4StatusLabel.Text = "Activo";
            this.Player4StatusLabel.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // SuspendedLabel
            // 
            this.SuspendedLabel.BackColor = System.Drawing.Color.LightPink;
            this.SuspendedLabel.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
            this.SuspendedLabel.Font = new System.Drawing.Font("Tahoma", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.SuspendedLabel.ForeColor = System.Drawing.Color.Black;
            this.SuspendedLabel.Location = new System.Drawing.Point(151, 230);
            this.SuspendedLabel.Name = "SuspendedLabel";
            this.SuspendedLabel.Size = new System.Drawing.Size(121, 28);
            this.SuspendedLabel.TabIndex = 30;
            this.SuspendedLabel.Text = "Suspendido...";
            this.SuspendedLabel.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            this.SuspendedLabel.Visible = false;
            // 
            // Player1DescriptionLabel
            // 
            this.Player1DescriptionLabel.BackColor = System.Drawing.Color.Transparent;
            this.Player1DescriptionLabel.Font = new System.Drawing.Font("Tahoma", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.Player1DescriptionLabel.ForeColor = System.Drawing.Color.Black;
            this.Player1DescriptionLabel.Location = new System.Drawing.Point(4, 209);
            this.Player1DescriptionLabel.Name = "Player1DescriptionLabel";
            this.Player1DescriptionLabel.Size = new System.Drawing.Size(99, 29);
            this.Player1DescriptionLabel.TabIndex = 41;
            this.Player1DescriptionLabel.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // Player2DescriptionLabel
            // 
            this.Player2DescriptionLabel.BackColor = System.Drawing.Color.Transparent;
            this.Player2DescriptionLabel.Font = new System.Drawing.Font("Tahoma", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.Player2DescriptionLabel.ForeColor = System.Drawing.Color.Black;
            this.Player2DescriptionLabel.Location = new System.Drawing.Point(109, 209);
            this.Player2DescriptionLabel.Name = "Player2DescriptionLabel";
            this.Player2DescriptionLabel.Size = new System.Drawing.Size(99, 29);
            this.Player2DescriptionLabel.TabIndex = 42;
            this.Player2DescriptionLabel.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // Player3DescriptionLabel
            // 
            this.Player3DescriptionLabel.BackColor = System.Drawing.Color.Transparent;
            this.Player3DescriptionLabel.Font = new System.Drawing.Font("Tahoma", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.Player3DescriptionLabel.ForeColor = System.Drawing.Color.Black;
            this.Player3DescriptionLabel.Location = new System.Drawing.Point(214, 209);
            this.Player3DescriptionLabel.Name = "Player3DescriptionLabel";
            this.Player3DescriptionLabel.Size = new System.Drawing.Size(99, 29);
            this.Player3DescriptionLabel.TabIndex = 43;
            this.Player3DescriptionLabel.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // Player4DescriptionLabel
            // 
            this.Player4DescriptionLabel.BackColor = System.Drawing.Color.Transparent;
            this.Player4DescriptionLabel.Font = new System.Drawing.Font("Tahoma", 6.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.Player4DescriptionLabel.ForeColor = System.Drawing.Color.Black;
            this.Player4DescriptionLabel.Location = new System.Drawing.Point(319, 209);
            this.Player4DescriptionLabel.Name = "Player4DescriptionLabel";
            this.Player4DescriptionLabel.Size = new System.Drawing.Size(99, 29);
            this.Player4DescriptionLabel.TabIndex = 44;
            this.Player4DescriptionLabel.TextAlign = System.Drawing.ContentAlignment.MiddleCenter;
            // 
            // Player4LayPrice
            // 
            this.Player4LayPrice.Available = 0D;
            this.Player4LayPrice.Back = false;
            this.Player4LayPrice.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("Player4LayPrice.BackgroundImage")));
            this.Player4LayPrice.Cursor = System.Windows.Forms.Cursors.Hand;
            this.Player4LayPrice.Eliminated = false;
            this.Player4LayPrice.ForeColor = System.Drawing.Color.Black;
            this.Player4LayPrice.Location = new System.Drawing.Point(368, 242);
            this.Player4LayPrice.MarketID = 0;
            this.Player4LayPrice.Name = "Player4LayPrice";
            this.Player4LayPrice.Size = new System.Drawing.Size(50, 35);
            this.Player4LayPrice.TabIndex = 38;
            this.Player4LayPrice.Click += new System.EventHandler(this.SelectionClicked);
            // 
            // Player3LayPrice
            // 
            this.Player3LayPrice.Available = 0D;
            this.Player3LayPrice.Back = false;
            this.Player3LayPrice.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("Player3LayPrice.BackgroundImage")));
            this.Player3LayPrice.Cursor = System.Windows.Forms.Cursors.Hand;
            this.Player3LayPrice.Eliminated = false;
            this.Player3LayPrice.ForeColor = System.Drawing.Color.Black;
            this.Player3LayPrice.Location = new System.Drawing.Point(263, 242);
            this.Player3LayPrice.MarketID = 0;
            this.Player3LayPrice.Name = "Player3LayPrice";
            this.Player3LayPrice.Size = new System.Drawing.Size(50, 35);
            this.Player3LayPrice.TabIndex = 37;
            this.Player3LayPrice.Click += new System.EventHandler(this.SelectionClicked);
            // 
            // Player2LayPrice
            // 
            this.Player2LayPrice.Available = 0D;
            this.Player2LayPrice.Back = false;
            this.Player2LayPrice.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("Player2LayPrice.BackgroundImage")));
            this.Player2LayPrice.Cursor = System.Windows.Forms.Cursors.Hand;
            this.Player2LayPrice.Eliminated = false;
            this.Player2LayPrice.ForeColor = System.Drawing.Color.Black;
            this.Player2LayPrice.Location = new System.Drawing.Point(158, 242);
            this.Player2LayPrice.MarketID = 0;
            this.Player2LayPrice.Name = "Player2LayPrice";
            this.Player2LayPrice.Size = new System.Drawing.Size(50, 35);
            this.Player2LayPrice.TabIndex = 36;
            this.Player2LayPrice.Click += new System.EventHandler(this.SelectionClicked);
            // 
            // Player1LayPrice
            // 
            this.Player1LayPrice.Available = 0D;
            this.Player1LayPrice.Back = false;
            this.Player1LayPrice.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("Player1LayPrice.BackgroundImage")));
            this.Player1LayPrice.Cursor = System.Windows.Forms.Cursors.Hand;
            this.Player1LayPrice.Eliminated = false;
            this.Player1LayPrice.ForeColor = System.Drawing.Color.Black;
            this.Player1LayPrice.Location = new System.Drawing.Point(53, 242);
            this.Player1LayPrice.MarketID = 0;
            this.Player1LayPrice.Name = "Player1LayPrice";
            this.Player1LayPrice.Size = new System.Drawing.Size(50, 35);
            this.Player1LayPrice.TabIndex = 35;
            this.Player1LayPrice.Click += new System.EventHandler(this.SelectionClicked);
            // 
            // Player4Price
            // 
            this.Player4Price.Available = 0D;
            this.Player4Price.Back = true;
            this.Player4Price.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("Player4Price.BackgroundImage")));
            this.Player4Price.Cursor = System.Windows.Forms.Cursors.Hand;
            this.Player4Price.Eliminated = false;
            this.Player4Price.ForeColor = System.Drawing.Color.Black;
            this.Player4Price.Location = new System.Drawing.Point(319, 242);
            this.Player4Price.MarketID = 0;
            this.Player4Price.Name = "Player4Price";
            this.Player4Price.Size = new System.Drawing.Size(50, 35);
            this.Player4Price.TabIndex = 34;
            this.Player4Price.Click += new System.EventHandler(this.SelectionClicked);
            // 
            // Player3Price
            // 
            this.Player3Price.Available = 0D;
            this.Player3Price.Back = true;
            this.Player3Price.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("Player3Price.BackgroundImage")));
            this.Player3Price.Cursor = System.Windows.Forms.Cursors.Hand;
            this.Player3Price.Eliminated = false;
            this.Player3Price.ForeColor = System.Drawing.Color.Black;
            this.Player3Price.Location = new System.Drawing.Point(214, 242);
            this.Player3Price.MarketID = 0;
            this.Player3Price.Name = "Player3Price";
            this.Player3Price.Size = new System.Drawing.Size(50, 35);
            this.Player3Price.TabIndex = 33;
            this.Player3Price.Click += new System.EventHandler(this.SelectionClicked);
            // 
            // Player2Price
            // 
            this.Player2Price.Available = 0D;
            this.Player2Price.Back = true;
            this.Player2Price.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("Player2Price.BackgroundImage")));
            this.Player2Price.Cursor = System.Windows.Forms.Cursors.Hand;
            this.Player2Price.Eliminated = false;
            this.Player2Price.ForeColor = System.Drawing.Color.Black;
            this.Player2Price.Location = new System.Drawing.Point(109, 242);
            this.Player2Price.MarketID = 0;
            this.Player2Price.Name = "Player2Price";
            this.Player2Price.Size = new System.Drawing.Size(50, 35);
            this.Player2Price.TabIndex = 32;
            this.Player2Price.Click += new System.EventHandler(this.SelectionClicked);
            // 
            // Player1Price
            // 
            this.Player1Price.Available = 0D;
            this.Player1Price.Back = true;
            this.Player1Price.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("Player1Price.BackgroundImage")));
            this.Player1Price.Cursor = System.Windows.Forms.Cursors.Hand;
            this.Player1Price.Eliminated = false;
            this.Player1Price.ForeColor = System.Drawing.Color.Black;
            this.Player1Price.Location = new System.Drawing.Point(4, 242);
            this.Player1Price.MarketID = 0;
            this.Player1Price.Name = "Player1Price";
            this.Player1Price.Size = new System.Drawing.Size(50, 35);
            this.Player1Price.TabIndex = 31;
            this.Player1Price.Click += new System.EventHandler(this.SelectionClicked);
            // 
            // TexasHoldemView
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
            this.BackColor = System.Drawing.SystemColors.Control;
            this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
            this.Controls.Add(this.SuspendedLabel);
            this.Controls.Add(this.Player4LayPrice);
            this.Controls.Add(this.Player3LayPrice);
            this.Controls.Add(this.Player2LayPrice);
            this.Controls.Add(this.Player1LayPrice);
            this.Controls.Add(this.Player4Price);
            this.Controls.Add(this.Player3Price);
            this.Controls.Add(this.Player2Price);
            this.Controls.Add(this.Player1Price);
            this.Controls.Add(this.Player4StatusLabel);
            this.Controls.Add(Player4Label);
            this.Controls.Add(this.Player3StatusLabel);
            this.Controls.Add(Player3Label);
            this.Controls.Add(this.Player2StatusLabel);
            this.Controls.Add(Player2Label);
            this.Controls.Add(this.Player1StatusLabel);
            this.Controls.Add(Player1Label);
            this.Controls.Add(CommunityCardsLabel);
            this.Controls.Add(this.ProgressGrey);
            this.Controls.Add(this.ProgressBar);
            this.Controls.Add(this.RiverLabel);
            this.Controls.Add(this.TurnLabel);
            this.Controls.Add(this.FlopLabel);
            this.Controls.Add(this.PreFlopLabel);
            this.Controls.Add(this.DealLabel);
            this.Controls.Add(this.GameTitleLabel);
            this.Controls.Add(this.Player4Card2);
            this.Controls.Add(this.Player4Card1);
            this.Controls.Add(this.Player3Card2);
            this.Controls.Add(this.Player3Card1);
            this.Controls.Add(this.Player2Card2);
            this.Controls.Add(this.Player2Card1);
            this.Controls.Add(this.Player1Card2);
            this.Controls.Add(this.Player1Card1);
            this.Controls.Add(this.CommunityCard5);
            this.Controls.Add(this.CommunityCard4);
            this.Controls.Add(this.CommunityCard3);
            this.Controls.Add(this.CommunityCard2);
            this.Controls.Add(this.CommunityCard1);
            this.Controls.Add(this.Player4DescriptionLabel);
            this.Controls.Add(this.Player3DescriptionLabel);
            this.Controls.Add(this.Player2DescriptionLabel);
            this.Controls.Add(this.Player1DescriptionLabel);
            this.Location = new System.Drawing.Point(-1, 60);
            this.Name = "TexasHoldemView";
            this.Size = new System.Drawing.Size(426, 393);
            ((System.ComponentModel.ISupportInitialize)(this.CommunityCard1)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.CommunityCard2)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.CommunityCard3)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.CommunityCard4)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.CommunityCard5)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player1Card1)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player1Card2)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player2Card2)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player2Card1)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player3Card2)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player3Card1)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player4Card2)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.Player4Card1)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.ProgressBar)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.ProgressGrey)).EndInit();
            this.ResumeLayout(false);

        }
        #endregion

        /// <summary>
        /// Updates all the game data in the panel
        /// </summary>
        public channelSnapshot CurrentChannelSnapshot
        {
            get
            {
                return channelSnapshot;
            }
            set
            {
                channelSnapshot = value;
                _UpdateDisplay();
            }
        }

        /// <summary>
        /// Redraw view
        /// </summary>
		private void _UpdateDisplay() 
		{
            // make things easier
            gameData = channelSnapshot.channel.game.gameData;
            market = channelSnapshot.channel.game.markets.market[0];

            if (market.selections.selection == null)
            {
                return;
            }

            player1Selection = market.selections.selection[0];
            player2Selection = market.selections.selection[1];
            player3Selection = market.selections.selection[2];
            player4Selection = market.selections.selection[3];

            // only do some painting once
            if (roundId != channelSnapshot.channel.game.round)
            {
                _PaintGameInfoOnce();
                _PaintCardsOnce();
                _PaintMarketDataOnce();
            }

            //Vemos cuando debemos actualizar el cdigo de round para que se llame al control de apuestas
            if (channelSnapshot.channel.game.markets.market[0].status == marketStatusEnum.ACTIVE ||
                channelSnapshot.channel.game.markets.market[0].status == marketStatusEnum.SUSPENDED_GAME_SETTLING)
            {
                if (channelSnapshot.channel.game.markets.market[0].status == marketStatusEnum.ACTIVE)
                {
                    //Esperamos a que se actualicen tambin las cuotas de los jugadores
                    Boolean ok = m_Parent.WPFControl.ChequearQuotas();

                    if (ok) roundId = channelSnapshot.channel.game.round;
                }
                else
                {
                    roundId = channelSnapshot.channel.game.round;
                }
            }
            
            //Si el nmero de round ha cambiado respecto al anterior llamamos al control de apuestas del WPF
            if (roundId != m_Parent.WPFControl.roundId)
            {
                m_Parent.WPFControl.roundId = roundId;

                m_Parent.WPFControl.ControlApuestas(channelSnapshot.channel.game.markets.market[0].status);
            }

            UpdateProgressBar(channelSnapshot, ProgressGrey, ProgressBar);
            _PaintMarketData();
		}

        /// <summary>
        /// Game info to paint once per round
        /// </summary>
        private void _PaintGameInfoOnce()
        {
            // set title
            GameTitleLabel.Text = channelSnapshot.channel.name;

            // set round
            _SetRound();
        }

        /// <summary>
        /// Card info to paint once
        /// </summary>
        private void _PaintCardsOnce()
        {
            Player1Card1.Image = GetCardResourceImage(gameData[0].property[0].value, false);
            Player1Card2.Image = GetCardResourceImage(gameData[0].property[1].value, false);

            Player2Card1.Image = GetCardResourceImage(gameData[1].property[0].value, false);
            Player2Card2.Image = GetCardResourceImage(gameData[1].property[1].value, false);

            Player3Card1.Image = GetCardResourceImage(gameData[2].property[0].value, false);
            Player3Card2.Image = GetCardResourceImage(gameData[2].property[1].value, false);

            Player4Card1.Image = GetCardResourceImage(gameData[3].property[0].value, false);
            Player4Card2.Image = GetCardResourceImage(gameData[3].property[1].value, false);

            gameDataObject community = gameData[4];
            CommunityCard1.Image = GetCardResourceImage(community.property[0].value, true);
            CommunityCard2.Image = GetCardResourceImage(community.property[1].value, true);
            CommunityCard3.Image = GetCardResourceImage(community.property[2].value, true);
            CommunityCard4.Image = GetCardResourceImage(community.property[3].value, true);
            CommunityCard5.Image = GetCardResourceImage(community.property[4].value, true);
        }

        /// <summary>
        /// Paint market data once for round
        /// </summary>
        private void _PaintMarketDataOnce()
        {
            // update selection status
            SetPlayerStatus(player1Selection.status, Player1StatusLabel, Player1Price, Player1LayPrice);
            SetPlayerStatus(player2Selection.status, Player2StatusLabel, Player2Price, Player2LayPrice);
            SetPlayerStatus(player3Selection.status, Player3StatusLabel, Player3Price, Player3LayPrice);
            SetPlayerStatus(player4Selection.status, Player4StatusLabel, Player4Price, Player4LayPrice);

            // update description text
            SetPlayerDescription(gameData[0].description, Player1DescriptionLabel);
            SetPlayerDescription(gameData[1].description, Player2DescriptionLabel);
            SetPlayerDescription(gameData[2].description, Player3DescriptionLabel);
            SetPlayerDescription(gameData[3].description, Player4DescriptionLabel);
        }

        /// <summary>
        /// Paint market data on every update
        /// </summary>
        private void _PaintMarketData()
        {
            // 
            // Check if the market is active. If not then we need to clear all the bets
            if (market.status != marketStatusEnum.ACTIVE)
            {
                ClearBets();
                _ToggleBetLayPanels(false);

                if (SuspendedLabel.Visible == false)
                {
                    SuspendedLabel.Show();
                }
            }
            else
            {
                if (SuspendedLabel.Visible == true)
                {
                    SuspendedLabel.Hide();
                }

                _ToggleBetLayPanels(true);

                // update prices and money
                if (player1Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    SetOddsPanel(Player1Price, market.id, player1Selection);
                    SetOddsPanel(Player1LayPrice, market.id, player1Selection);
                }

                if (player2Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    SetOddsPanel(Player2Price, market.id, player2Selection);
                    SetOddsPanel(Player2LayPrice, market.id, player2Selection);
                }

                if (player3Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    SetOddsPanel(Player3Price, market.id, player3Selection);
                    SetOddsPanel(Player3LayPrice, market.id, player3Selection);
                }

                if (player4Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    SetOddsPanel(Player4Price, market.id, player4Selection);
                    SetOddsPanel(Player4LayPrice, market.id, player4Selection);
                }
            }
        }

		/// <summary>
		/// Enables or disables the buttons allowing bets to be placed
		/// </summary>
		/// <param name="enabled"></param>
		private void _ToggleBetLayPanels(bool enabled)
		{
            // remove the price and available if we are disabling the panel
            if (enabled == false)
            {
                Player1Price.Clear();
                Player1LayPrice.Clear();

                Player2Price.Clear();
                Player2LayPrice.Clear();

                Player3Price.Clear();
                Player3LayPrice.Clear();

                Player4Price.Clear();
                Player4LayPrice.Clear();
            }

            Player1Price.Enabled = enabled;
            Player1LayPrice.Enabled = enabled;
            Player2Price.Enabled = enabled;
            Player2LayPrice.Enabled = enabled;
            Player3Price.Enabled = enabled;
            Player3LayPrice.Enabled = enabled;
            Player4Price.Enabled = enabled;
            Player4LayPrice.Enabled = enabled;
        }

        private void _SetRound()
        {
            DealLabel.Font = fn;
            PreFlopLabel.Font = fn;
            FlopLabel.Font = fn;
            TurnLabel.Font = fn;
            RiverLabel.Font = fn;

            switch (channelSnapshot.channel.game.round)
            {
                case 1:
                    DealLabel.Font = fb;
                    break;
                case 2:
                    PreFlopLabel.Font = fb;
                    break;
                case 3:
                    FlopLabel.Font = fb;
                    break;
                case 4:
                    TurnLabel.Font = fb;
                    break;
                case 5:
                    RiverLabel.Font = fb;
                    break;
            }
        }

        private void SelectionClicked(object sender, System.EventArgs e)
        {
            SelectionClicked(ShowBetPlacement, sender, channelSnapshot, m_Parent.Account);
        }

        private void OnClearBets()
        {
            if (ClearBets != null)
            {
                ClearBets();
            }
        }
    }
}
