﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.IO;
using System.Reflection;

using Betfair.Gamex.API.Entities;

using Poker.Classes;
using Poker.Controls;
using Poker.Controls.GameView;

//Clases para el control del juego y Linq
using Poker.WPFClasses;

namespace Poker
{
    /// <summary>
    /// Interaction logic for WPFApuestas.xaml
    /// </summary>
    /// 

    //Control WPF para simulación de apuestas automáticas
    public partial class WPFApuestas : UserControl
    {
        public Juego objJuego;
        public Jugador J1, J2, J3, J4;
        public double TotalSaldo, TotalGanado, TotalPérdidas, UltimaGanancia, apuestas, cant_comienzo;
        public double ApuestaFavor, ApuestaContra;
        public int roundId;
        public TexasHoldemView TexasControl;

        //La matriz de apuestas contendrá las apuestas que se realicen en cada partida
        private double[,] MatrizApuestas = new double[4, 4];

        public MainForm FPrincipal;

        //Constructor
        public WPFApuestas()
        {
            InitializeComponent();

            grid1.IsEnabled = true;

            //Creamos las apuestas
            ListEstrategia.Items.Add("Apostar en contra del favorito en el round 2");
            ListEstrategia.Items.Add("Apostar al favorito en el round 4");
            ListEstrategia.Items.Add("Apostar al favorito en el round 4 con algoritmo de recuperación de pérdidas");
            ListEstrategia.Items.Add("Apostar a favor de 2 jugadores en el round 1");
            ListEstrategia.Items.Add("Apostar a favor de 3 jugadores en el round 1");


            try
            {
                //Cargamos el nombre de instancia del servidor SQL Server
                StreamReader re = File.OpenText("database.config");
                string input = re.ReadLine();

                TextInstancia.Text = input;
            }
            catch (Exception e)
            {
            }
        }

        //Devuelve si una cadena es un número o no
        //Parámetros: Expression -> la expresión que debe ser parseada
        public bool IsNumeric(object Expression)
        {
            bool isNum;
            double retNum;

            isNum = Double.TryParse(Convert.ToString(Expression), System.Globalization.NumberStyles.Any, System.Globalization.NumberFormatInfo.InvariantInfo, out retNum);
            return isNum;
        }


        //Valida el formulario del control verificando que todos los datos han sido introducidos correctamente
        private Boolean validarForm()
        {
            Boolean ok = false;

            if (!IsNumeric(TextSaldo.Text))
            {
                ok = false;
                MessageBox.Show("El saldo total no es un número");
                TextGP.Focus();
            }
            else
            {
                if (!IsNumeric(TextFavor.Text))
                {
                    ok = false;
                    MessageBox.Show("El importe a apostar a favor no es un número");
                    TextFavor.Focus();
                }
                else
                {
                    if (!IsNumeric(TextContra.Text))
                    {
                        ok = false;
                        MessageBox.Show("El importe a apostar en contra no es un número");
                        TextContra.Focus();
                    }
                    else
                    {
                        if (Convert.ToDouble(TextFavor.Text) < 4 || Convert.ToDouble(TextContra.Text) < 4 ||
                            Convert.ToDouble(TextFavor.Text) > 1000 || Convert.ToDouble(TextContra.Text) > 1000)
                        {
                            ok = false;
                            MessageBox.Show("El importe a apostar a favor y en contra deben de estar comprendidos entre 4 y 1000");
                            TextFavor.Focus();
                        }
                        else
                        {
                            if (Convert.ToDouble(TextSaldo.Text) < 0)
                            {
                                ok = false;
                                MessageBox.Show("El importe del saldo no puede ser negativo");
                                TextSaldo.Focus();
                            }
                            else
                            {
                                if (CheckGrabar.IsChecked.Value && TextInstancia.Text.Trim() == "")
                                {
                                    ok = false;
                                    MessageBox.Show("La instancia a la base de datos no puede estar vacía");
                                    TextInstancia.Focus();
                                }
                                else
                                {
                                    ok = true;
                                }
                            }
                        }
                    }
                }
            }

            return ok;
        }

        //Comienza o termina el juego
        private void BtnComenzar_Click(object sender, RoutedEventArgs e)
        {
            if (groupBox1.IsEnabled)
            {
                if (validarForm())
                {
                    FPrincipal.StartGame();
                    CrearObjetos();
                    BtnComenzar.Content = "Terminar juego";
                    groupBox1.IsEnabled = false;
                    groupBox2.IsEnabled = false;
                    groupBox3.IsEnabled = false;
                    objJuego.FechaComienzo=Convert.ToDateTime("1900-01-01");
                }
            }
            else
            {
                FPrincipal.EndGame();
                TexasControl = null;
                objJuego.FechaComienzo = Convert.ToDateTime("1900-01-01");
                BtnComenzar.Content = "Comenzar juego";
                groupBox1.IsEnabled = true;
                groupBox2.IsEnabled = true;
                groupBox3.IsEnabled = true;
            }
        }

        //Crea e inicializa los objetos necesarios para el proceso de apuestas
        private void CrearObjetos()
        {
            TotalSaldo = Convert.ToDouble(TextSaldo.Text);
            ApuestaFavor = Convert.ToDouble(TextFavor.Text);
            ApuestaContra = Convert.ToDouble(TextContra.Text);

            TexasControl = (TexasHoldemView)FPrincipal.m_ActiveGameControl;

            TotalGanado = 0;
            TotalPérdidas = 0;
            UltimaGanancia = 0;
            apuestas = 0;
            cant_comienzo = TotalSaldo;

            TextG.Text = "Total ganancias: " +  TotalGanado.ToString();
            TextP.Text = "Total pérdidas: " + TotalPérdidas.ToString();
            TextGP.Text = "Ganancias/pérdidas partida anterior: " + UltimaGanancia.ToString();
            TextGPCurso.Text = "Gasto en apuestas: " + apuestas.ToString();

            if (TexasControl.roundId!=1) reinicializar();
        }

        
        //Reinicia los objetos cuando comienza una nueva partida
        private void reinicializar()
        {
            MatrizApuestas = new double[4, 4];

            objJuego = new Juego();

            J1 = new Jugador();
            J2 = new Jugador();
            J3 = new Jugador();
            J4 = new Jugador();

            J1.Jugador1 = 1;
            J2.Jugador1 = 2;
            J3.Jugador1 = 3;
            J4.Jugador1 = 4;

            ListApuestas.Items.Clear();
        }

        
        //Controla el desarrollo de las apuestas
        //Parámetros: status -> Indica el estado de la partida
        public void ControlApuestas(marketStatusEnum status)
        {
            if (TexasControl.roundId == 1) reinicializar();
            
            asignarValores();

            if (status != marketStatusEnum.SUSPENDED_GAME_SETTLING)
            {
                switch (TexasControl.roundId)
                {
                    case 1:
                        round1();
                        break;
                    case 2:
                        round2();
                        break;
                    case 3:
                        break;
                    case 4:
                        round4();
                        break;
                }
            }
            else
            {
                round5();
            }
        }

        //Chequea las cuotas de los jugadores ya que debido al multithread puede que todavía no se hayan cargado
        public Boolean ChequearQuotas()
        {
            Boolean ok = true;
            double cuota;

            try
            {
                if (TexasControl.player1Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    cuota = TexasControl.player1Selection.bestAvailableToBackPrices[0].Value;
                    cuota = TexasControl.player1Selection.bestAvailableToLayPrices[0].Value;
                }

                if (TexasControl.player2Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    cuota = TexasControl.player2Selection.bestAvailableToBackPrices[0].Value;
                    cuota = TexasControl.player2Selection.bestAvailableToLayPrices[0].Value;
                }

                if (TexasControl.player3Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    cuota = TexasControl.player3Selection.bestAvailableToBackPrices[0].Value;
                    cuota = TexasControl.player3Selection.bestAvailableToLayPrices[0].Value;
                }

                if (TexasControl.player4Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    cuota = TexasControl.player4Selection.bestAvailableToBackPrices[0].Value;
                    cuota = TexasControl.player4Selection.bestAvailableToLayPrices[0].Value;
                }
            }
            catch (Exception e)
            {
                ok = false;
            }

            return ok;
        }

        //Asigna los valoes de las cartas y las cuotas a los objetos en memoria
        private void asignarValores()
        {
            gameDataObject community = TexasControl.gameData[4];

            objJuego.Carta1 = community.property[0].value;
            objJuego.Carta2 = community.property[1].value;
            objJuego.Carta3 = community.property[2].value;
      
            if (community.property[3].value != "NOT AVAILABLE")
            {
                objJuego.Carta4 = community.property[3].value;
            }
            else
            {
                objJuego.Carta4 = "-1";
            }

            if (community.property[4].value != "NOT AVAILABLE")
            {
                objJuego.Carta5 = community.property[4].value;
            }
            else
            {
                objJuego.Carta5 = "-1";
            }

            J1.Carta1 = TexasControl.gameData[0].property[0].value;
            J1.Carta2 = TexasControl.gameData[0].property[1].value;

            J2.Carta1 = TexasControl.gameData[1].property[0].value;
            J2.Carta2 = TexasControl.gameData[1].property[1].value;

            J3.Carta1 = TexasControl.gameData[2].property[0].value;
            J3.Carta2 = TexasControl.gameData[2].property[1].value;

            J4.Carta1 = TexasControl.gameData[3].property[0].value;
            J4.Carta2 = TexasControl.gameData[3].property[1].value;

            roundId = TexasControl.roundId;

            if (roundId == 1)
            {
                J1.CuotaFavor1 = TexasControl.player1Selection.bestAvailableToBackPrices[0].Value;
                J1.CuotaContra1 = TexasControl.player1Selection.bestAvailableToLayPrices[0].Value;

                J2.CuotaFavor1 = TexasControl.player2Selection.bestAvailableToBackPrices[0].Value;
                J2.CuotaContra1 = TexasControl.player2Selection.bestAvailableToLayPrices[0].Value;

                J3.CuotaFavor1 = TexasControl.player3Selection.bestAvailableToBackPrices[0].Value;
                J3.CuotaContra1 = TexasControl.player3Selection.bestAvailableToLayPrices[0].Value;

                J4.CuotaFavor1 = TexasControl.player4Selection.bestAvailableToBackPrices[0].Value;
                J4.CuotaContra1 = TexasControl.player4Selection.bestAvailableToLayPrices[0].Value;
            }

            if (roundId == 2)
            {
                J1.CuotaFavor2 = TexasControl.player1Selection.bestAvailableToBackPrices[0].Value;
                J1.CuotaContra2 = TexasControl.player1Selection.bestAvailableToLayPrices[0].Value;

                J2.CuotaFavor2 = TexasControl.player2Selection.bestAvailableToBackPrices[0].Value;
                J2.CuotaContra2 = TexasControl.player2Selection.bestAvailableToLayPrices[0].Value;

                J3.CuotaFavor2 = TexasControl.player3Selection.bestAvailableToBackPrices[0].Value;
                J3.CuotaContra2 = TexasControl.player3Selection.bestAvailableToLayPrices[0].Value;

                J4.CuotaFavor2 = TexasControl.player4Selection.bestAvailableToBackPrices[0].Value;
                J4.CuotaContra2 = TexasControl.player4Selection.bestAvailableToLayPrices[0].Value;
            }

            if (roundId == 3)
            {
                if (TexasControl.player1Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    J1.CuotaFavor3 = TexasControl.player1Selection.bestAvailableToBackPrices[0].Value;
                    J1.CuotaContra3 = TexasControl.player1Selection.bestAvailableToLayPrices[0].Value;
                }

                if (TexasControl.player2Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    J2.CuotaFavor3 = TexasControl.player2Selection.bestAvailableToBackPrices[0].Value;
                    J2.CuotaContra3 = TexasControl.player2Selection.bestAvailableToLayPrices[0].Value;
                }

                if (TexasControl.player3Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    J3.CuotaFavor3 = TexasControl.player3Selection.bestAvailableToBackPrices[0].Value;
                    J3.CuotaContra3 = TexasControl.player3Selection.bestAvailableToLayPrices[0].Value;
                }

                if (TexasControl.player4Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    J4.CuotaFavor3 = TexasControl.player4Selection.bestAvailableToBackPrices[0].Value;
                    J4.CuotaContra3 = TexasControl.player4Selection.bestAvailableToLayPrices[0].Value;
                }
            }

            if (roundId == 4)
            {
                if (TexasControl.player1Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    J1.CuotaFavor4 = TexasControl.player1Selection.bestAvailableToBackPrices[0].Value;
                    J1.CuotaContra4 = TexasControl.player1Selection.bestAvailableToLayPrices[0].Value;
                }

                if (TexasControl.player2Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    J2.CuotaFavor4 = TexasControl.player2Selection.bestAvailableToBackPrices[0].Value;
                    J2.CuotaContra4 = TexasControl.player2Selection.bestAvailableToLayPrices[0].Value;
                }

                if (TexasControl.player3Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    J3.CuotaFavor4 = TexasControl.player3Selection.bestAvailableToBackPrices[0].Value;
                    J3.CuotaContra4 = TexasControl.player3Selection.bestAvailableToLayPrices[0].Value;
                }

                if (TexasControl.player4Selection.status == selectionStatusEnum.IN_PLAY)
                {
                    J4.CuotaFavor4 = TexasControl.player4Selection.bestAvailableToBackPrices[0].Value;
                    J4.CuotaContra4 = TexasControl.player4Selection.bestAvailableToLayPrices[0].Value;
                }
            }
        }

        //Reinicia la matriz de apuestas
        private void reiniciarMatriz()
        {
            MatrizApuestas = new double[4, 4];
        }

        
        //Calcula si la apuestas puede ser realizada en función del saldo disponible en la cartera
        //Parámetros: TotalSaldo: el saldo total disponible en la cuenta
        //            Apuestas: el importe a apostar
        //            Cuota: la cuota del jugador
        private Boolean QuedaSaldo(double TotalSaldo, double Apuesta, double Cuota = 0)
        {
            if (Apuesta > 0)
            {
                if ((TotalSaldo - Apuesta) > 0)
                    return true;
                else
                    return false;
            }
            else
            {
                if (TotalSaldo + (Apuesta * Cuota) > 0)
                    return true;
                else
                    return false;
            }
        }

        //Realiza una apuesta
        //Parámetros: i -> fila de la matriz que indica el jugador
        //            a -> columna de la matriz que indica el round en el que se debe apostar
        //            importe -> la cantidad a apostar
        private void Apostar(int i, int a, double importe)
        {
            string cadena="";
            double cuota=obtenerCuota(i,a,importe);

            if (QuedaSaldo(TotalSaldo, importe, cuota))
            {
                MatrizApuestas[i, a] = importe;
                
                TotalSaldo -= Math.Abs(importe);
                apuestas -= Math.Abs(importe);

                TextP.Text = "Total pérdidas: " + Math.Round(TotalPérdidas).ToString();
                TextSaldo.Text = Math.Round(TotalSaldo,2).ToString();
                TextGPCurso.Text = "Gasto en apuestas: " + Math.Round(apuestas,2).ToString();

                cadena = Math.Abs(importe).ToString() +" euros apostados a ";

                cadena += cuota.ToString();
            
                if (importe>0)
                    cadena+=" a favor ";
                else
                    cadena+=" en contra ";
            
                cadena+="en el round " + roundId + " al jugador " + (i+1);

                ListApuestas.Items.Add (cadena);
            }
        }

        //Realiza las apuestas en el round1
        private void round1()
        {
            string estrategia = (string)ListEstrategia.SelectedItem;

            reiniciarMatriz();

            apuestas = 0;
            TextGPCurso.Text = "Gasto en apuestas: " + apuestas.ToString();

            objJuego.FechaComienzo = DateTime.Now;

            switch (estrategia)
            {
                case "Apostar a favor de 2 jugadores en el round 1":
                    Apostar(0, 0, ApuestaFavor);
                    Apostar(1, 0, ApuestaFavor);
                    break;
                case "Apostar a favor de 3 jugadores en el round 1":
                    Apostar(0, 0, ApuestaFavor);
                    Apostar(1, 0, ApuestaFavor);
                    Apostar(2, 0, ApuestaFavor);
                    break;
            }
        }

        //Realiza las apuestas en el round2
        private void round2()
        {
            string estrategia = (string)ListEstrategia.SelectedItem;

            switch (estrategia)
            {
                case "Apostar en contra del favorito en el round 2":
                    Apostar(Convert.ToInt32(ObtenerFavorito(true)), 1, -ApuestaContra);
                    break;
            }
        }

        //Realiza las apuestas en el round4
        private void round4()
        {
            string estrategia = (string)ListEstrategia.SelectedItem;

            switch (estrategia)
            {
                case "Apostar al favorito en el round 4":
                    Apostar(Convert.ToInt32(ObtenerFavorito(true)), 3, ApuestaFavor);
                    break;
                case "Apostar al favorito en el round 4 con algoritmo de recuperación de pérdidas":
                    Apostar(Convert.ToInt32(ObtenerFavorito(true)), 3, AlgoritmoRecuperacionPerdida(ObtenerFavorito(false)));
                    break;
            }
        }

        //Calcula mediante una ecuación lineal el importe que se debe apostar dada una cuota para recuperar el dinero
        //perdido en el anterior juego
        //Parámetros: cuota -> la cuota del jugador del que se quiere realizar la apuesta
        private double AlgoritmoRecuperacionPerdida(double cuota)
        {
            //Apuesta mínima en BetFair
            double resultado = 4;
            
            if (UltimaGanancia < 0)
            {

                /*Ecuación líneal que viene de x * cuota = x + ultima_pérdida para la obtención del dinero perdido
                  a la que además se le debe de sumar el 2.5% que se quedaría Betfair de beneficio*/
                resultado = (Math.Abs(UltimaGanancia) / (cuota - 1)) + (((Math.Abs(UltimaGanancia) / (cuota - 1)) * 2.5) / 100);

                /*Si la apuesta es <4 ó >1000 Betfair no dejará hacerla, por lo que la igualamos a 4 para que haga la apuesta
                  mínima*/
                if (resultado < 4 || resultado > 1000) resultado = 4;
            }

            return Math.Round(resultado,2);
        }

        //Obtiene el jugador favorito en el round en curso
        //Parámetros: jug_favorito -> indica si lo que se ha de retornar es el número del jugador favorito o su cuota
        private double ObtenerFavorito(Boolean jug_favorito)
        {
            double cuota = 1000000;
            int favorito = 0;

            if (TexasControl.player1Selection.status == selectionStatusEnum.IN_PLAY &&
                TexasControl.player1Selection.bestAvailableToBackPrices[0].Value < cuota)
            {
                cuota = TexasControl.player1Selection.bestAvailableToBackPrices[0].Value;
                favorito = 0;
            }

            if (TexasControl.player2Selection.status == selectionStatusEnum.IN_PLAY &&
                TexasControl.player2Selection.bestAvailableToBackPrices[0].Value < cuota)
            {
                cuota = TexasControl.player2Selection.bestAvailableToBackPrices[0].Value;
                favorito = 1;
            }

            if (TexasControl.player3Selection.status == selectionStatusEnum.IN_PLAY &&
                TexasControl.player3Selection.bestAvailableToBackPrices[0].Value < cuota)
            {
                cuota = TexasControl.player3Selection.bestAvailableToBackPrices[0].Value;
                favorito = 2;
            }

            if (TexasControl.player4Selection.status == selectionStatusEnum.IN_PLAY &&
                TexasControl.player4Selection.bestAvailableToBackPrices[0].Value < cuota)
            {
                cuota = TexasControl.player4Selection.bestAvailableToBackPrices[0].Value;
                favorito = 3;
            }

            if (jug_favorito)
                return favorito;
            else
                return cuota;
        }

        //Obtiene la cuota de un jugador en un round concreto
        //Parámetros: i -> indica el jugador
        //            a -> indica el round
        private double obtenerCuota(int i, int a)
        {
            return obtenerCuota(i, a, MatrizApuestas[i, a]);
        }

        //Obtiene la cuota de un jugador en un round concreto
        //Parámetros: i -> indica el jugador
        //            a -> indica el round
        //            importe -> indica si ha de obtener la cuota a favor o en contra
        private double obtenerCuota(int i, int a, double importe)
        {
            var dValue = J1.CuotaFavor1;

            if (importe > 0)
            {
                switch (i)
                {
                    case 0:
                        switch (a)
                        {
                            case 0:
                                dValue = J1.CuotaFavor1;
                                break;
                            case 1:
                                dValue = J1.CuotaFavor2;
                                break;
                            case 2:
                                dValue = J1.CuotaFavor3;
                                break;
                            case 3:
                                dValue = J1.CuotaFavor4;
                                break;
                        }
                        break;
                    case 1:
                        switch (a)
                        {
                            case 0:
                                dValue = J2.CuotaFavor1;
                                break;
                            case 1:
                                dValue = J2.CuotaFavor2;
                                break;
                            case 2:
                                dValue = J2.CuotaFavor3;
                                break;
                            case 3:
                                dValue = J2.CuotaFavor4;
                                break;
                        }
                        break;
                    case 2:
                        switch (a)
                        {
                            case 0:
                                dValue = J3.CuotaFavor1;
                                break;
                            case 1:
                                dValue = J3.CuotaFavor2;
                                break;
                            case 2:
                                dValue = J3.CuotaFavor3;
                                break;
                            case 3:
                                dValue = J3.CuotaFavor4;
                                break;
                        }
                        break;
                    case 3:
                        switch (a)
                        {
                            case 0:
                                dValue = J4.CuotaFavor1;
                                break;
                            case 1:
                                dValue = J4.CuotaFavor2;
                                break;
                            case 2:
                                dValue = J4.CuotaFavor3;
                                break;
                            case 3:
                                dValue = J4.CuotaFavor4;
                                break;
                        }
                        break;
                }
            }
            else
            {
                switch (i)
                {
                    case 0:
                        switch (a)
                        {
                            case 0:
                                dValue = J1.CuotaContra1;
                                break;
                            case 1:
                                dValue = J1.CuotaContra2;
                                break;
                            case 2:
                                dValue = J1.CuotaContra3;
                                break;
                            case 3:
                                dValue = J1.CuotaContra4;
                                break;
                        }
                        break;
                    case 1:
                        switch (a)
                        {
                            case 0:
                                dValue = J2.CuotaContra1;
                                break;
                            case 1:
                                dValue = J2.CuotaContra2;
                                break;
                            case 2:
                                dValue = J2.CuotaContra3;
                                break;
                            case 3:
                                dValue = J2.CuotaContra4;
                                break;
                        }
                        break;
                    case 2:
                        switch (a)
                        {
                            case 0:
                                dValue = J3.CuotaContra1;
                                break;
                            case 1:
                                dValue = J3.CuotaContra2;
                                break;
                            case 2:
                                dValue = J3.CuotaContra3;
                                break;
                            case 3:
                                dValue = J3.CuotaContra4;
                                break;
                        }
                        break;
                    case 3:
                        switch (a)
                        {
                            case 0:
                                dValue = J4.CuotaContra1;
                                break;
                            case 1:
                                dValue = J4.CuotaContra2;
                                break;
                            case 2:
                                dValue = J4.CuotaContra3;
                                break;
                            case 3:
                                dValue = J4.CuotaContra4;
                                break;
                        }
                        break;
                }
            }

            return Convert.ToDouble(dValue);
        }

        //Esta función calcula el resultado de las apuestas cuando concluye el juego, sea éste en el round 5 como es normal o
        //en el round 4 como algunas veces puede ocurrir
        private void round5()
        {
            int number_winners = 0;
            selectionStatusEnum status = 0;
            double dValue = 0;
            double current_perdidas = 0, current_ganancias = 0;

            J1.ResultadoId = Convert.ToInt32(TexasControl.player1Selection.status);
            J2.ResultadoId = Convert.ToInt32(TexasControl.player2Selection.status);
            J3.ResultadoId = Convert.ToInt32(TexasControl.player3Selection.status);
            J4.ResultadoId = Convert.ToInt32(TexasControl.player4Selection.status);

            //Si no hay ninguna apuesta en el sistema no tenemos que calcular nada
            if (apuestas != 0)
            {
                if (TexasControl.player1Selection.status == selectionStatusEnum.WINNER ||
                    TexasControl.player1Selection.status == selectionStatusEnum.TIED_DEAD_HEAT)

                    number_winners++;

                if (TexasControl.player2Selection.status == selectionStatusEnum.WINNER ||
                    TexasControl.player2Selection.status == selectionStatusEnum.TIED_DEAD_HEAT)

                    number_winners++;

                if (TexasControl.player3Selection.status == selectionStatusEnum.WINNER ||
                    TexasControl.player3Selection.status == selectionStatusEnum.TIED_DEAD_HEAT)

                    number_winners++;

                if (TexasControl.player4Selection.status == selectionStatusEnum.WINNER ||
                    TexasControl.player4Selection.status == selectionStatusEnum.TIED_DEAD_HEAT)

                    number_winners++;

                for (var i = 0; i < MatrizApuestas.GetLength(1); i++)
                {
                    for (var a = 0; a < MatrizApuestas.GetLength(0); a++)
                    {
                        if (MatrizApuestas[i, a] != 0)
                        {
                            switch (i)
                            {
                                case 0:
                                    status = TexasControl.player1Selection.status;
                                    break;
                                case 1:
                                    status = TexasControl.player2Selection.status;
                                    break;
                                case 2:
                                    status = TexasControl.player3Selection.status;
                                    break;
                                case 3:
                                    status = TexasControl.player4Selection.status;
                                    break;
                            }

                            dValue = obtenerCuota(i, a);

                            if (MatrizApuestas[i, a] > 0)
                            {
                                if (status == selectionStatusEnum.WINNER ||
                                    status == selectionStatusEnum.TIED_DEAD_HEAT)
                                {
                                    //Betfair se lleva un 2.50% de beneficio de la ganancia obtenida
                                    //Fórmula: (importe apostado * (cuota/número de ganadores)) - 2.50%
                                    current_ganancias += ((MatrizApuestas[i, a] * (dValue / number_winners)) - ((MatrizApuestas[i, a] * (dValue / number_winners) * 2.50) / 100)); // +MatrizApuestas[i, a];
                                }
                                else
                                {
                                    //No hace falta porque descontamos la apuesta cuando se realiza
                                    //current_perdidas -= MatrizApuestas[i, a];

                                    //Si hemos perdido la apuesta se suma al saldo de dinero pérdido.
                                    //TotalPérdidas += MatrizApuestas[i, a];
                                }
                            }
                            else
                            {
                                if (status == selectionStatusEnum.LOSER)
                                {
                                    //Betfair se lleva un 2.50% de beneficio de la ganancia obtenida
                                    //Fórmula: importe apostado + (importe apostado - 2.50%)
                                    current_ganancias += Math.Abs(MatrizApuestas[i, a]) + (Math.Abs(MatrizApuestas[i, a]) - ((Math.Abs(MatrizApuestas[i, a]) * 2.50) / 100));
                                }
                                else
                                {
                                    //Fórmula: (importe apostado * cuota) - importa apostado
                                    current_perdidas += (MatrizApuestas[i, a] * dValue) - MatrizApuestas[i, a];
                                }
                            }
                        }
                    }
                }


                if (current_ganancias + current_perdidas != 0)
                {
                    UltimaGanancia = TotalSaldo;
                    TotalSaldo += current_ganancias + current_perdidas;
                    UltimaGanancia = TotalSaldo - UltimaGanancia;
                }
                else
                {
                    UltimaGanancia = apuestas;
                }

                if (TotalSaldo - cant_comienzo > 0)
                {
                    TotalGanado = TotalSaldo - cant_comienzo; //+= current_ganancias;
                    TotalPérdidas = 0;
                }
                else
                {
                    TotalPérdidas = TotalSaldo - cant_comienzo; //-= current_perdidas;
                    TotalGanado = 0;
                }

                TextSaldo.Text = Math.Round(TotalSaldo, 2).ToString();
                TextGP.Text = "Ganancias/pérdidas partida anterior: " + Math.Round(UltimaGanancia, 2).ToString();
                TextGPCurso.Text = "Gasto en apuestas: 0";
                TextP.Text = "Total pérdidas: " + Math.Round(TotalPérdidas, 2).ToString();
                TextG.Text = "Total ganancias: " + Math.Round(TotalGanado, 2).ToString();
                ListApuestas.Items.Clear();
            }

            GrabarJuego();
        }

        //Graba la partida en la base de datos
        private void GrabarJuego()
        {
            // Northwnd inherits from System.Data.Linq.DataContext.
            //Po nw = new Juego1(@"Poker.mdf");
            //SQLClasesDataContext Poker = new SQLClasesDataContext(@"Poker.mdf");

            if ((objJuego.FechaComienzo != Convert.ToDateTime("1900-01-01")) && CheckGrabar.IsChecked.Value)
            {
                SQLClasesDataContext Poker;

                try
                {
                   Poker = new SQLClasesDataContext("Server=" + TextInstancia.Text + ";Database=Poker;Trusted_Connection=True");

                    objJuego.FechaFin = DateTime.Now;

                    Poker.Juegos.InsertOnSubmit(objJuego);

                    Poker.SubmitChanges();

                    J1.JuegoId = objJuego.JuegoId;
                    J2.JuegoId = objJuego.JuegoId;
                    J3.JuegoId = objJuego.JuegoId;
                    J4.JuegoId = objJuego.JuegoId;

                    Poker.Jugadors.InsertOnSubmit(J1);
                    Poker.Jugadors.InsertOnSubmit(J2);
                    Poker.Jugadors.InsertOnSubmit(J3);
                    Poker.Jugadors.InsertOnSubmit(J4);

                    Poker.SubmitChanges();
                }
                catch (Exception e)
                {
                    MessageBox.Show("Se produjo un fallo al intentar grabar la partida en la base de datos." +
                                    "Compruebe que el nombre de la instancia es correcta y que en ella existe la base de datos" +
                                    "Poker. Si este error sigue ocurriendo desactive por favor la opción de grabar la partida en la base de datos.");
                }

            }
        }

        //Muestra la descripción de cada estrategia
        private void ListEstrategia_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            string estrategia = (string)ListEstrategia.SelectedItem;
            Stream s = null;
            
            Assembly a = Assembly.Load("Poker");

            switch (estrategia)
            {
                case "Apostar a favor de 2 jugadores en el round 1":
                    s = a.GetManifestResourceStream("Poker.WPFClasses.Resources.2jug_r_1.txt");
                    break;
                case "Apostar a favor de 3 jugadores en el round 1":
                    s = a.GetManifestResourceStream("Poker.WPFClasses.Resources.3jug_r_1.txt");
                    break;
                case "Apostar en contra del favorito en el round 2":
                    s = a.GetManifestResourceStream("Poker.WPFClasses.Resources.contra_fav_r_2.txt");
                    break;
                case "Apostar al favorito en el round 4":
                    s = a.GetManifestResourceStream("Poker.WPFClasses.Resources.fav_r_4.txt");
                    break;
                case "Apostar al favorito en el round 4 con algoritmo de recuperación de pérdidas":
                    s = a.GetManifestResourceStream("Poker.WPFClasses.Resources.fav_r_4_algo.txt");
                    break;
            }

            if (s != null)
            {
                using (Stream stream = s)
                {
                    byte[] buffer = new byte[stream.Length];
                    stream.Read(buffer, 0, buffer.Length);
                    TextDescripcion.Text = Encoding.Default.GetString(buffer);
                } 
            }
        }

        //Guarda el nombre de la instancia de SQL Server en un fichero
        private void BtnGuardar_Click(object sender, RoutedEventArgs e)
        {
            System.IO.StreamWriter file = new System.IO.StreamWriter("database.config");

            try
            {
                file.WriteLine(TextInstancia.Text);
            }
            catch (Exception ex)
            {
                MessageBox.Show("Se produjo un error al intentar grabar el fichero de configuración.");
            }
            finally
            {
                file.Close();
            }
        }
    }
}
